SystemOrganization addCategory: #ConfigurationOfRefactoringBrowser!

Object subclass: #ConfigurationOfRefactoringBrowser
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfRefactoringBrowser'!

!ConfigurationOfRefactoringBrowser class methodsFor: 'private' stamp: 'MarianoMartinezPeck 12/18/2009 16:21'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfRefactoringBrowser class methodsFor: 'private' stamp: 'DaleHenrichs 12/29/2009 17:57'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion ]! !

!ConfigurationOfRefactoringBrowser class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/18/2009 16:21'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfRefactoringBrowser class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/18/2009 16:21'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfRefactoringBrowser class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/18/2009 16:21'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfRefactoringBrowser class methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 12/18/2009 16:21'!
project

	^self new project! !

!ConfigurationOfRefactoringBrowser methodsFor: 'baselines' stamp: 'MarianoMartinezPeck 1/6/2010 19:18'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].
	
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/rb'.
		spec 
			package: 'AST-Core';
			package: 'AST-Tests' with: [ spec requires: 'AST-Core' ];
			package: 'Refactoring-Core' with: [ spec requires: 'AST-Core' ];
			package: 'Refactoring-Tests' with: [ spec requires: 'Refactoring-Core' ];
			package: 'Refactoring-Spelling' with: [ spec requires: 'Refactoring-Core' ].

		spec
			group: 'default' with: #('Core' );
			group: 'Core' with: #( 'AST-Core' 'Refactoring-Core' 'Refactoring-Spelling' );
			group: 'Tests' with: #( 'AST-Tests' 'Refactoring-Tests' );
			group: 'Core Tests' with: #('Core' 'Tests' );
			
			yourself.
	]! !

!ConfigurationOfRefactoringBrowser methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 12/18/2009 16:21'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfRefactoringBrowser methodsFor: 'versions' stamp: 'MarianoMartinezPeck 1/6/2010 23:03'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'MarianoMartinezPeck'.
		spec description: 'First release 1.0 of this project '.
	].

	spec for: #pharo do: [	
		spec 
			package: 'AST-Core' with: 'AST-Core-lr.49';
			package: 'AST-Tests' with: 'AST-Tests-lr.5';
			package: 'Refactoring-Core' with: 'Refactoring-Core-lr.94';
			package: 'Refactoring-Tests' with: 'Refactoring-Tests-TestRunner.29';
			package: 'Refactoring-Spelling' with: 'Refactoring-Spelling-lr.9'.

	]
			! !
